Watson-Mail
===========

Easily compose and send email via sendmail or SMTP.

For full documentation please see [Read The
Docs](http://watson-mail.readthedocs.org/).

Build Status
------------

[![Build
Status](https://img.shields.io/travis/watsonpy/watson-mail.svg?maxAge=2592000)](https://travis-ci.org/watsonpy/watson-mail)
[![Coverage
Status](https://img.shields.io/coveralls/watsonpy/watson-mail.svg?maxAge=2592000)](https://coveralls.io/r/watsonpy/watson-mail)
[![Version](https://img.shields.io/pypi/v/watson-mail.svg?maxAge=2592000)](https://pypi.python.org/pypi/watson-mail/)

### Installation

`pip install watson-mail`

### Dependencies

-   watson-common
